Learn R Programming

rayrender (version 0.41.3)

render_preview: Render Preview

Description

Takes the scene description and renders an image, either to the device or to a filename.

Usage

render_preview(..., light_direction = c(0, -1, 0), exponent = 6)

Value

Raytraced plot to current device, or an image saved to a file.

Arguments

...

All arguments that would be passed to `render_scene()`.

light_direction

Default `c(0,-1,0)`. Vector specifying the orientation for the global light using for phong shading.

exponent

Default `6`. Phong exponent.

Examples

Run this code
if (FALSE) { # interactive() || identical(Sys.getenv("IN_PKGDOWN"), "true")
generate_ground(material=diffuse(color="darkgreen")) |>
  add_object(sphere(material=diffuse(checkercolor="red"))) |>
  render_preview()
#Change the light direction
generate_ground(material=diffuse(color="darkgreen")) |>
  add_object(sphere(material=diffuse(checkercolor="red"))) |>
  render_preview(light_direction = c(-1,-1,0))
#Change the Phong exponent
generate_ground(material=diffuse(color="darkgreen")) |>
  add_object(sphere(material=diffuse(checkercolor="red"))) |>
  render_preview(light_direction = c(-1,-1,0), exponent=100)
}

Run the code above in your browser using DataLab